@@ -12,12 +12,15 @@ rb = pp.Suppress(']')
 colon = pp.Suppress(':')
 pipe = pp.Suppress('|')
 slash = pp.Suppress('/')
+backslash = pp.Suppress('\\')
 name = pp.Word(pp.alphas + '_', pp.alphanums + '_')
 quoted = pp.QuotedString('"', escChar='\\') | pp.QuotedString("'", escChar='\\')
 plus = pp.Literal('+')
 integer = ppc.signed_integer
 numeric_quoted = S('#') + ((S("'") + ppc.number + S("'")) | (S('"') + ppc.number + S('"')))
 
+reserved = '.[]*:|+?/'
+
 # atomic ops
 appender = pp.Literal('+').setParseAction(el.Appender)
 appender_unique = pp.Literal('+?').setParseAction(el.AppenderUnique)
@@ -25,7 +28,8 @@ appender_unique = pp.Literal('+?').setParseAction(el.AppenderUnique)
 numeric_key = (numeric_quoted | integer).setParseAction(el.NumericQuoted)
 numeric_slot = (numeric_quoted | ppc.number).setParseAction(el.Numeric)
 
-word = pp.Word(pp.alphanums + '_').setParseAction(el.Word)
+#word = pp.Word(pp.alphanums + '_').setParseAction(el.Word)
+word = (pp.Optional(backslash) + pp.CharsNotIn(reserved)).setParseAction(el.Word)
 string = quoted.copy().setParseAction(el.String)
 wildcard = pp.Literal('*').setParseAction(el.Wildcard)
 wildcard_first = pp.Literal('*?').setParseAction(el.WildcardFirst)
@@ -36,7 +40,7 @@ slice = pp.Optional(integer | plus) + ':' + pp.Optional(integer | plus) \
          + pp.Optional(':') + pp.Optional(integer | plus)
 
 _commons = string | wildcard_first | wildcard | regex_first | regex
-key = (numeric_key | word | _commons).setParseAction(el.Key)
+key = (numeric_key | _commons | word).setParseAction(el.Key)
 slot = (lb + (numeric_slot | _commons) + rb).setParseAction(el.Slot)
 slotspecial = (lb + (appender_unique | appender) + rb).setParseAction(el.SlotSpecial)
 slotslice = (lb + pp.Optional(slice) + rb).setParseAction(el.Slice)
@@ -47,7 +51,7 @@ dotted_top = key | slot | slotspecial | slotslice
 #dotted_invert = (pp.Suppress('-') + dotted_top).setParseAction(el.Invert)
 dotted = invert + dotted_top + pp.ZeroOrMore(multi)
 
-targ = quoted | ppc.number | pp.Regex(r'[^|:]*')
+targ = quoted | ppc.number | pp.CharsNotIn('|:')
 transform = pp.Group(name.copy() + pp.ZeroOrMore(colon + targ))
 transforms = pp.ZeroOrMore(pipe + transform)
 
